@@ -155,12 +155,7 @@ void KWalletManager::configUI() {
     }
     KStandardAction::quit(this, SLOT(shuttingDown()), actionCollection());
 
-#if KXMLGUI_VERSION >= QT_VERSION_CHECK(5, 84, 0)
     KStandardAction::keyBindings(guiFactory(), &KXMLGUIFactory::showConfigureShortcutsDialog, actionCollection());
-#else
-    KStandardAction::keyBindings(guiFactory(), SLOT(configureShortcuts()),
-                                 actionCollection());
-#endif
 
     setupGUI(Keys | Save | Create, QStringLiteral("kwalletmanager.rc"));
     setStandardToolBarMenuEnabled(false);
